@@ -16,8 +16,8 @@ dfree <- function(data, matrix_clusters)
 
   nb_clusters <- ncol(matrix_clusters)
 
-  mean_in <- matrix(sapply(1:nb_clusters, function(cl) colMeans(matrix(data[matrix_clusters[,cl]==1,], ncol = nb_permu))), ncol = nb_clusters)
-  mean_out <- matrix(sapply(1:nb_clusters, function(cl) colMeans(matrix(data[matrix_clusters[,cl]==0,], ncol = nb_permu))), ncol = nb_clusters)
+  mean_in <- matrix(sapply(1:nb_clusters, function(cl) colMeans(data[matrix_clusters[,cl]==1,, drop = FALSE])), ncol = nb_clusters)
+  mean_out <- matrix(sapply(1:nb_clusters, function(cl) colMeans(data[matrix_clusters[,cl]==0,, drop = FALSE])), ncol = nb_clusters)
 
   stat <- matrix(sapply(1:nb_clusters, function(cl) sqrt(sum(matrix_clusters[,cl]) * (nb_sites - sum(matrix_clusters[,cl])) ) * (mean_in[,cl] - mean_out[,cl])), ncol = nb_clusters)
 
