@@ -32,10 +32,11 @@ UNP <- function(data, MC = 999, typeI = 0.05, initialization, permutations){
     if(nrow(matrix_clusters)!=length(data)){
       stop("The number of sites must be the same in the matrix of clusters and in the data")
     }
-
+    cat("Computation of the scan statistic \n")
     rank_data <- rank(data, ties.method = "average")
     index <- wmw_uni(matrix(rank_data, ncol = 1), matrix_clusters)
-
+    cat("---Done--- \n")
+    cat("Estimation of the statistical significance \n")
     nb_clusters <- ncol(matrix_clusters)
     nb_sites <- nrow(matrix_clusters)
     generation_signif <- sapply(1:MC, function(g) rank_data[permutations[g,]])
@@ -44,7 +45,8 @@ UNP <- function(data, MC = 999, typeI = 0.05, initialization, permutations){
 
     stat_MC <- rowMaxs(results)
     pvals <- sapply(1:nb_clusters, function(j) (length(which(stat_MC >= index[1,j]))+1)/(MC+1))
-
+    cat("---Done--- \n")
+    cat("Finalization \n")
     index_clusters_temp <- which(pvals <= typeI)
 
     finalization <- FinScan(index_clusters_temp, index, filtering_post, type_minimaxi_post, mini_post, maxi_post, nb_sites, matrix_clusters, radius, areas, centres, pvals)
@@ -93,9 +95,10 @@ UG <- function(data, MC = 999, typeI = 0.05, initialization, permutations){
     if(nrow(matrix_clusters)!=length(data)){
       stop("The number of sites must be the same in the matrix of clusters and in the data")
     }
-
+    cat("Computation of the scan statistic \n")
     index <- dfree(matrix(data, ncol = 1), matrix_clusters)
-
+    cat("---Done--- \n")
+    cat("Estimation of the statistical significance \n")
     nb_clusters <- ncol(matrix_clusters)
     nb_sites <- nrow(matrix_clusters)
     generation_signif <- sapply(1:MC, function(g) data[permutations[g,]])
@@ -104,7 +107,8 @@ UG <- function(data, MC = 999, typeI = 0.05, initialization, permutations){
 
     stat_MC <- rowMaxs(results)
     pvals <- sapply(1:nb_clusters, function(j) (length(which(stat_MC >= index[1,j]))+1)/(MC+1))
-
+    cat("---Done--- \n")
+    cat("Finalization \n")
     index_clusters_temp <- which(pvals <= typeI)
 
     finalization <- FinScan(index_clusters_temp, index, filtering_post, type_minimaxi_post, mini_post, maxi_post, nb_sites, matrix_clusters, radius, areas, centres, pvals)
